aic: Akaike Information Criterion (AIC)

View source: R/allgenerics.R

aicR Documentation

Akaike Information Criterion (AIC)

Description

Generic function computing the Akaike Information Criterion of the model x, with the list of sequences sequences.

Usage

aic(x, sequences, ncpu = 2)

Arguments

x

An object for which the log-likelihood of the DMM can be computed.

sequences

A vector of characters or a list of vector of characters representing the sequences for which the AIC will be computed based on x.

ncpu

Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.

Value

A list of AIC (numeric)

Author(s)

Victor Mataigne, Alexandre Seiller

References

\insertRef

BaVe2018drimmR \insertRefVer08drimmR


drimmR documentation built on Oct. 9, 2026, 5:08 p.m.