| aic.dmm | R Documentation |
Computation of the Akaike Information Criterion.
## S3 method for class 'dmm'
aic(x, sequences, ncpu = 2)
x |
An object of class |
sequences |
A character vector or a list of character vector representing the sequences for which the AIC will be computed based on |
ncpu |
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores. |
A list of AIC (numeric)
Victor Mataigne, Alexandre Seiller
BaVe2018drimmR \insertRefVer08drimmR
fitdmm, getTransitionMatrix, loglik, aic
data(lambda, package = "drimmR")
sequence <- c("a","g","g","t","c","g","a","t","a","a","a")
dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum")
aic(dmm,sequence)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.