| bic | R Documentation |
Generic function computing the Bayesian Information Criterion
of the model x, with the list of sequences sequences.
bic(x, sequences, ncpu = 2)
x |
An object for which the log-likelihood of the DMM can be computed. |
sequences |
A list of vectors representing the sequences for which the BIC will be computed based on |
ncpu |
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores. |
A list of BIC (numeric)
Victor Mataigne, Alexandre Seiller
BaVe2018drimmR \insertRefVer08drimmR
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.