| drimmR-package | R Documentation |
This package performs the estimation, simulation and the exact computation of associated reliability measures of drifting Markov models (DMMs). These are particular non-homogeneous Markov chains for which the Markov transition matrix is a linear (polynomial) function of two (several) Markov transition matrices. Several statistical frameworks are taken into account (one or several samples, complete or incomplete samples, models of the same length). Computation of probabilities of appearance of a word along a sequence under a given model are also considered.
Maintainer: Nicolas Vergne nicolas.vergne@univ-rouen.fr (<nicolas.vergne@univ-rouen.fr>)
Authors:
Corentin Lothodé (<corentin.lothode@univ-angers.fr>)
Alexandre Seiller
Vlad Stefan Barbu (<vladstefan.barbu@univ-rouen.fr>)
Other contributors:
Victor Mataigne [contributor]
Arnaud Lefebvre [contributor]
Annthomy Gilles [contributor]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.