getDistribution: Distributions of the drifting Markov Model

View source: R/allgenerics.R

getDistributionR Documentation

Distributions of the drifting Markov Model

Description

Generic function evaluating the distribution of a model x at a given position pos or at every position all.pos

Usage

getDistribution(x, pos, all.pos = FALSE, internal = FALSE, ncpu = 2)

Arguments

x

An object for which the distributions of the DMM can be computed.

pos

A positive integer giving the position along the sequence on which the distribution of the DMM should be computed

all.pos

'FALSE' (evaluation at position index) ; 'TRUE' (evaluation for all position indices)

internal

'FALSE' (default) ; 'TRUE' (for internal use of the distributions function)

ncpu

Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.

Details

Distribution at position l is evaluated by \mu_{l} =\mu_0 \prod_{t=k}^{l} \ \pi_{\frac{t}{n}}, \forall l \ge k, k \in N^* order of the DMM

Value

A vector or matrix of distribution probabilities

Author(s)

Alexandre Seiller

References

\insertRef

BaVe2018drimmR \insertRefVer08drimmR


drimmR documentation built on Oct. 9, 2026, 5:08 p.m.