getDistribution.dmm: Get the distributions of the DMM

View source: R/dmm.R

getDistribution.dmmR Documentation

Get the distributions of the DMM

Description

Evaluate the distribution of the DMM at a given position or at every position

Usage

## S3 method for class 'dmm'
getDistribution(x, pos, all.pos = FALSE, internal = FALSE, ncpu = 2)

Arguments

x

An object of class dmm

pos

A positive integer giving the position along the sequence on which the distribution of the DMM should be computed

all.pos

'FALSE' (default, evaluation at position index) ; 'TRUE' (evaluation for all position indices)

internal

'FALSE' (default) ; 'TRUE' (for internal use of distributions function)

ncpu

Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.

Details

Distribution at position l is evaluated by \mu_{l} =\mu_0 \prod_{t=k}^{l} \ \pi_{\frac{t}{n}}, \forall l \ge k, k \in N^* order of the DMM

Value

A vector or matrix of distribution probabilities

Author(s)

Alexandre Seiller

References

\insertRef

BaVe2018drimmR \insertRefVer08drimmR

See Also

fitdmm, getTransitionMatrix, distributions, getStationaryLaw

Examples

data(lambda, package = "drimmR")
dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum")
t <- 10
getDistribution(dmm,pos=t)

drimmR documentation built on Oct. 9, 2026, 5:08 p.m.