getStationaryLaw: Stationary laws of the drifting Markov Model

View source: R/allgenerics.R

getStationaryLawR Documentation

Stationary laws of the drifting Markov Model

Description

Generic function evaluating the stationary law of a model x at a given position pos or at every position all.pos

Usage

getStationaryLaw(x, pos, all.pos = FALSE, internal = FALSE, ncpu = 2)

Arguments

x

An object for which the stationary laws of the DMM can be computed.

pos

A positive integer giving the position along the sequence on which the stationary law of the DMM should be computed

all.pos

'FALSE' (default, evaluation at position index) ; 'TRUE' (evaluation for all position indices)

internal

'FALSE' (default) ; 'TRUE' (for internal use of the initial law computation)

ncpu

Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.

Details

Stationary law at position t is evaluated by solving \mu_t \ \pi_{\frac{t}{n}} = \mu

Value

A vector or matrix of stationary law probabilities

Author(s)

Alexandre Seiller

References

\insertRef

BaVe2018drimmR \insertRefVer08drimmR


drimmR documentation built on Oct. 9, 2026, 5:08 p.m.