getStationaryLaw.dmm: Get the stationary laws of the DMM

View source: R/dmm.R

getStationaryLaw.dmmR Documentation

Get the stationary laws of the DMM

Description

Evaluate the stationary law of the DMM at a given position or at every position

Usage

## S3 method for class 'dmm'
getStationaryLaw(x, pos, all.pos = FALSE, internal = FALSE, ncpu = 2)

Arguments

x

An object of class dmm

pos

A positive integer giving the position along the sequence on which the stationary law of the DMM should be computed

all.pos

'FALSE' (default, evaluation at position index) ; 'TRUE' (evaluation for all position indices)

internal

'FALSE' (default) ; 'TRUE' (for internal use of th initial law of fitdmm and word applications)

ncpu

Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.

Details

Stationary law at position t is evaluated by solving \mu_t \ \pi_{\frac{t}{n}} = \mu

Value

A vector or matrix of stationary law probabilities

Author(s)

Alexandre Seiller

References

\insertRef

BaVe2018drimmR \insertRefVer08drimmR

See Also

fitdmm, getTransitionMatrix, stationary_distributions, getDistribution

Examples

data(lambda, package = "drimmR")
dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum")
t <- 10
getStationaryLaw(dmm,pos=t)

drimmR documentation built on Oct. 9, 2026, 5:08 p.m.