getTransitionMatrix: Transition matrix of the drifting Markov Model

View source: R/allgenerics.R

getTransitionMatrixR Documentation

Transition matrix of the drifting Markov Model

Description

Generic function evaluating the transition matrix of a model x at a given position pos

Usage

getTransitionMatrix(x, pos)

Arguments

x

An object for which the transition matrices of the DMM can be computed.

pos

A positive integer giving the position along the sequence on which the transition matrix of the DMM should be computed

Value

A transition matrix at a given position

Author(s)

Victor Mataigne, Alexandre Seiller

References

\insertRef

BaVe2018drimmR \insertRefVer08drimmR


drimmR documentation built on Oct. 9, 2026, 5:08 p.m.