getTransitionMatrix.dmm: Get transition matrix of the drifting Markov Model

View source: R/dmm.R

getTransitionMatrix.dmmR Documentation

Get transition matrix of the drifting Markov Model

Description

Evaluate the transition matrix of the DMM at a given position

Usage

## S3 method for class 'dmm'
getTransitionMatrix(x, pos)

Arguments

x

An object of class dmm

pos

A positive integer giving the position along the sequence on which the transition matrix of the DMM should be computed

Value

A transition matrix at a given position

Author(s)

Victor Mataigne, Alexandre Seiller

References

\insertRef

BaVe2018drimmR \insertRefVer08drimmR

See Also

fitdmm

Examples

data(lambda, package = "drimmR")
dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'),init.estim = "freq", fit.method="sum")
t <- 10
getTransitionMatrix(dmm,pos=t)

drimmR documentation built on Oct. 9, 2026, 5:08 p.m.