loglik: Log-likelihood of the drifting Markov Model

View source: R/allgenerics.R

loglikR Documentation

Log-likelihood of the drifting Markov Model

Description

Generic function computing the log-likelihood of the model x, with the list of sequences sequences.

Usage

loglik(x, sequences, ncpu = 2)

Arguments

x

An object for which the log-likelihood of the DMM can be computed.

sequences

A vector of character or list of vectors representing the sequences for which the

ncpu

Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores. log-likelihood of the model must be computed.

Value

A list of loglikelihood (numeric)

Author(s)

Annthomy Gilles, Alexandre Seiller

References

\insertRef

BaVe2018drimmR \insertRefVer08drimmR


drimmR documentation built on Oct. 9, 2026, 5:08 p.m.