Learn R Programming

drimmR (version 1.0.3)

loglik.dmm: Evaluate the log-likelihood of a drifting Markov Model

Description

Evaluate the log-likelihood of a drifting Markov Model

Usage

# S3 method for dmm
loglik(x, sequences, ncpu = 2)

Value

A list of log-likelihood (numeric)

Arguments

x

An object of class dmm

sequences

A character vector or a list of character vectors representing the sequence

ncpu

Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.

Author

Annthomy Gilles, Alexandre Seiller

References

BaVe2018drimmR Ver08drimmR

See Also

fitdmm, getTransitionMatrix

Examples

Run this code
data(lambda, package = "drimmR")
sequence <- c("a","g","g","t","c","g","a","t","a","a","a")
dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum")
loglik(dmm,sequence)

Run the code above in your browser using DataLab