simulate: Simulate a sequence under a drifting Markov model

View source: R/allgenerics.R

simulateR Documentation

Simulate a sequence under a drifting Markov model

Description

Generic function simulating a sequence of length model_size under a model x

Usage

simulate(x, output_file, model_size = 1e+05, ncpu = 2)

Arguments

x

An object for which simulated sequences of the DMM can be computed.

output_file

(Optional) File containing the simulated sequence (e.g, "C:/.../SIM.txt")

model_size

Size of the model

ncpu

Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.

Value

the vector of simulated sequence

Author(s)

Annthomy Gilles, Alexandre Seiller

References

\insertRef

BaVe2018drimmR \insertRefVer08drimmR


drimmR documentation built on Oct. 9, 2026, 5:08 p.m.