stationary_distributions: Stationary laws for a range of positions between <start> and...

View source: R/metrics.R

stationary_distributionsR Documentation

Stationary laws for a range of positions between <start> and <end>

Description

Stationary laws for a range of positions between <start> and <end>

Usage

stationary_distributions(
  x,
  start = 1,
  end = NULL,
  step = NULL,
  output_file = NULL,
  plot = FALSE
)

Arguments

x

An object of class dmm

start

Start position : a positive integer giving the start position along the sequence from which the stationary laws of the DMM should be computed

end

End position : a positive integer giving the end position along the sequence until which the stationary laws of the DMM should be computed

step

A step (integer)

output_file

(Optional) A file containing matrix of stationary laws (e.g, "C:/.../SL.txt")

plot

FALSE (default); TRUE (display a figure plot of stationary distribution probabilities by position)

Value

A matrix with positions and stationary laws of states

Author(s)

Alexandre Seiller

References

\insertRef

BaVe2018drimmR \insertRefVer08drimmR

See Also

fitdmm, getStationaryLaw

Examples

data(lambda, package = "drimmR")
dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq",fit.method="sum")
stationary_distributions(dmm,start=1,end=1000,step=100, plot=TRUE)

drimmR documentation built on Oct. 9, 2026, 5:08 p.m.