| word_probability | R Documentation |
Probability of a word at a position t of a DMM
word_probability(word, pos, x, output_file = NULL, internal = FALSE, ncpu = 2)
word |
A subsequence (string of characters) |
pos |
A position (numeric) |
x |
An object of class |
output_file |
(Optional) A file containing the probability (e.g,"C:/.../PROB.txt") |
internal |
|
ncpu |
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores. |
A numeric, probability of word
Victor Mataigne, Alexandre Seiller
BaVe2018drimmR \insertRefVer08drimmR
fitdmm, getTransitionMatrix, word_probabilities, words_probabilities
data(lambda, package = "drimmR")
dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum")
word_probability("aggctga",4,dmm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.