| words_probabilities | R Documentation |
Probability of appearance of several words at several positions of a DMM
words_probabilities(words, pos, x, output_file = NULL, plot = FALSE)
words |
A vector of characters containing words |
pos |
A vector of integer positions |
x |
An object of class |
output_file |
(Optional) A file containing the matrix of probabilities (e.g,"C:/.../PROB.txt") |
plot |
|
A dataframe of word probabilities along the positions of the sequence
Victor Mataigne, Alexandre Seiller
BaVe2018drimmR \insertRefVer08drimmR
fitdmm, getTransitionMatrix, word_probability, word_probabilities
data(lambda, package = "drimmR")
dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq",
fit.method="sum")
words <- c("atcgattc", "taggct", "ggatcgg")
pos <- c(100,300)
words_probabilities(words=words,pos=pos,dmm,plot=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.