| aic | R Documentation |
Generic function computing the Akaike Information Criterion of
the model x, with the list of sequences sequences.
aic(x, sequences, ncpu = 2)
x |
An object for which the log-likelihood of the DMM can be computed. |
sequences |
A vector of characters or a list of vector of characters representing the sequences for which the AIC will be computed based on |
ncpu |
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores. |
A list of AIC (numeric)
Victor Mataigne, Alexandre Seiller
BaVe2018drimmR \insertRefVer08drimmR
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.