Generic function computing the Akaike Information Criterion of
the model x, with the list of sequences sequences.
aic(x, sequences, ncpu = 2)A list of AIC (numeric)
An object for which the log-likelihood of the DMM can be computed.
A vector of characters or a list of vector of characters representing the sequences for which the AIC will be computed based on x.
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.
Victor Mataigne, Alexandre Seiller
BaVe2018drimmR Ver08drimmR