Learn R Programming

drimmR (version 1.0.3)

bic.dmm: Evaluate the BIC of a drifting Markov Model

Description

Computation of the Bayesian Information Criterion.

Usage

# S3 method for dmm
bic(x, sequences, ncpu = 2)

Value

A list of BIC (numeric).

Arguments

x

An object of class dmm

sequences

A character vector or a list of character vector representing the sequences for which the BIC will be computed based on x.

ncpu

Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.

Author

Victor Mataigne, Alexandre Seiller

References

BaVe2018drimmR Ver08drimmR

See Also

fitdmm, getTransitionMatrix, loglik, bic

Examples

Run this code
data(lambda, package = "drimmR")
sequence <- c("a","g","g","t","c","g","a","t","a","a","a")
dmm<- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum")
bic(dmm,sequence)

Run the code above in your browser using DataLab