powered by
Computation of the Bayesian Information Criterion.
# S3 method for dmm bic(x, sequences, ncpu = 2)
A list of BIC (numeric).
An object of class dmm
dmm
A character vector or a list of character vector representing the sequences for which the BIC will be computed based on x.
x
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.
Victor Mataigne, Alexandre Seiller
BaVe2018drimmR Ver08drimmR
fitdmm, getTransitionMatrix, loglik, bic
data(lambda, package = "drimmR") sequence <- c("a","g","g","t","c","g","a","t","a","a","a") dmm<- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum") bic(dmm,sequence)
Run the code above in your browser using DataLab