| distributions | R Documentation |
Distributions for a range of positions between <start> and <end>
distributions(
x,
start = 1,
end = NULL,
step = NULL,
output_file = NULL,
plot = FALSE,
ncpu = 2
)
x |
An object of class |
start |
Start position : a positive integer giving the start position along the sequence from which the distributions of the DMM should be computed |
end |
End position : a positive integer giving the end position along the sequence until which the distributions of the DMM should be computed |
step |
A step (integer) |
output_file |
(Optional) A file containing matrix of distributions (e.g, "C:/.../DIST.txt") |
plot |
|
ncpu |
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores. |
A matrix with positions and distributions of states
Alexandre Seiller
BaVe2018drimmR \insertRefVer08drimmR
fitdmm, getDistribution, getStationaryLaw
data(lambda, package = "drimmR")
dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum")
distributions(dmm,start=1,end=1000,step=100, plot=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.