Learn R Programming

drimmR (version 1.0.3)

distributions: Distributions for a range of positions between <start> and <end>

Description

Distributions for a range of positions between <start> and <end>

Usage

distributions(
  x,
  start = 1,
  end = NULL,
  step = NULL,
  output_file = NULL,
  plot = FALSE,
  ncpu = 2
)

Value

A matrix with positions and distributions of states

Arguments

x

An object of class dmm

start

Start position : a positive integer giving the start position along the sequence from which the distributions of the DMM should be computed

end

End position : a positive integer giving the end position along the sequence until which the distributions of the DMM should be computed

step

A step (integer)

output_file

(Optional) A file containing matrix of distributions (e.g, "C:/.../DIST.txt")

plot

FALSE (default); TRUE (display a figure plot of distribution probabilities by position)

ncpu

Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.

Author

Alexandre Seiller

References

BaVe2018drimmR Ver08drimmR

See Also

fitdmm, getDistribution, getStationaryLaw

Examples

Run this code
# \donttest{
data(lambda, package = "drimmR")
dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum")
distributions(dmm,start=1,end=1000,step=100, plot=TRUE)
# }

Run the code above in your browser using DataLab