powered by
Distributions for a range of positions between <start> and <end>
distributions( x, start = 1, end = NULL, step = NULL, output_file = NULL, plot = FALSE, ncpu = 2 )
A matrix with positions and distributions of states
An object of class dmm
dmm
Start position : a positive integer giving the start position along the sequence from which the distributions of the DMM should be computed
End position : a positive integer giving the end position along the sequence until which the distributions of the DMM should be computed
A step (integer)
(Optional) A file containing matrix of distributions (e.g, "C:/.../DIST.txt")
FALSE (default); TRUE (display a figure plot of distribution probabilities by position)
FALSE
TRUE
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.
Alexandre Seiller
BaVe2018drimmR Ver08drimmR
fitdmm, getDistribution, getStationaryLaw
# \donttest{ data(lambda, package = "drimmR") dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum") distributions(dmm,start=1,end=1000,step=100, plot=TRUE) # }
Run the code above in your browser using DataLab