| getStationaryLaw | R Documentation |
Generic function evaluating the stationary law of a model x at a given position pos or at every position all.pos
getStationaryLaw(x, pos, all.pos = FALSE, internal = FALSE, ncpu = 2)
x |
An object for which the stationary laws of the DMM can be computed. |
pos |
A positive integer giving the position along the sequence on which the stationary law of the DMM should be computed |
all.pos |
'FALSE' (default, evaluation at position index) ; 'TRUE' (evaluation for all position indices) |
internal |
'FALSE' (default) ; 'TRUE' (for internal use of the initial law computation) |
ncpu |
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores. |
Stationary law at position t is evaluated by solving \mu_t \ \pi_{\frac{t}{n}} = \mu
A vector or matrix of stationary law probabilities
Alexandre Seiller
BaVe2018drimmR \insertRefVer08drimmR
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.