Generic function evaluating the stationary law of a model x at a given position pos or at every position all.pos
getStationaryLaw(x, pos, all.pos = FALSE, internal = FALSE, ncpu = 2)A vector or matrix of stationary law probabilities
An object for which the stationary laws of the DMM can be computed.
A positive integer giving the position along the sequence on which the stationary law of the DMM should be computed
`FALSE` (default, evaluation at position index) ; `TRUE` (evaluation for all position indices)
`FALSE` (default) ; `TRUE` (for internal use of the initial law computation)
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.
Alexandre Seiller
Stationary law at position t is evaluated by solving \(\mu_t \ \pi_{\frac{t}{n}} = \mu\)
BaVe2018drimmR Ver08drimmR