Learn R Programming

drimmR (version 1.0.3)

getStationaryLaw.dmm: Get the stationary laws of the DMM

Description

Evaluate the stationary law of the DMM at a given position or at every position

Usage

# S3 method for dmm
getStationaryLaw(x, pos, all.pos = FALSE, internal = FALSE, ncpu = 2)

Value

A vector or matrix of stationary law probabilities

Arguments

x

An object of class dmm

pos

A positive integer giving the position along the sequence on which the stationary law of the DMM should be computed

all.pos

`FALSE` (default, evaluation at position index) ; `TRUE` (evaluation for all position indices)

internal

`FALSE` (default) ; `TRUE` (for internal use of th initial law of fitdmm and word applications)

ncpu

Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.

Author

Alexandre Seiller

Details

Stationary law at position t is evaluated by solving \(\mu_t \ \pi_{\frac{t}{n}} = \mu\)

References

BaVe2018drimmR Ver08drimmR

See Also

fitdmm, getTransitionMatrix, stationary_distributions, getDistribution

Examples

Run this code
data(lambda, package = "drimmR")
dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum")
t <- 10
getStationaryLaw(dmm,pos=t)

Run the code above in your browser using DataLab