powered by
Evaluate the stationary law of the DMM at a given position or at every position
# S3 method for dmm getStationaryLaw(x, pos, all.pos = FALSE, internal = FALSE, ncpu = 2)
A vector or matrix of stationary law probabilities
An object of class dmm
dmm
A positive integer giving the position along the sequence on which the stationary law of the DMM should be computed
`FALSE` (default, evaluation at position index) ; `TRUE` (evaluation for all position indices)
`FALSE` (default) ; `TRUE` (for internal use of th initial law of fitdmm and word applications)
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.
Alexandre Seiller
Stationary law at position t is evaluated by solving \(\mu_t \ \pi_{\frac{t}{n}} = \mu\)
BaVe2018drimmR Ver08drimmR
fitdmm, getTransitionMatrix, stationary_distributions, getDistribution
data(lambda, package = "drimmR") dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum") t <- 10 getStationaryLaw(dmm,pos=t)
Run the code above in your browser using DataLab