| getTransitionMatrix | R Documentation |
Generic function evaluating the transition matrix of a model x at a given position pos
getTransitionMatrix(x, pos)
x |
An object for which the transition matrices of the DMM can be computed. |
pos |
A positive integer giving the position along the sequence on which the transition matrix of the DMM should be computed |
A transition matrix at a given position
Victor Mataigne, Alexandre Seiller
BaVe2018drimmR \insertRefVer08drimmR
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.