| getTransitionMatrix.dmm | R Documentation |
Evaluate the transition matrix of the DMM at a given position
## S3 method for class 'dmm'
getTransitionMatrix(x, pos)
x |
An object of class |
pos |
A positive integer giving the position along the sequence on which the transition matrix of the DMM should be computed |
A transition matrix at a given position
Victor Mataigne, Alexandre Seiller
BaVe2018drimmR \insertRefVer08drimmR
fitdmm
data(lambda, package = "drimmR")
dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'),init.estim = "freq", fit.method="sum")
t <- 10
getTransitionMatrix(dmm,pos=t)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.