| loglik | R Documentation |
Generic function computing the log-likelihood of the model x,
with the list of sequences sequences.
loglik(x, sequences, ncpu = 2)
x |
An object for which the log-likelihood of the DMM can be computed. |
sequences |
A vector of character or list of vectors representing the sequences for which the |
ncpu |
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores. log-likelihood of the model must be computed. |
A list of loglikelihood (numeric)
Annthomy Gilles, Alexandre Seiller
BaVe2018drimmR \insertRefVer08drimmR
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.