Learn R Programming

drimmR (version 1.0.3)

loglik: Log-likelihood of the drifting Markov Model

Description

Generic function computing the log-likelihood of the model x, with the list of sequences sequences.

Usage

loglik(x, sequences, ncpu = 2)

Value

A list of loglikelihood (numeric)

Arguments

x

An object for which the log-likelihood of the DMM can be computed.

sequences

A vector of character or list of vectors representing the sequences for which the

ncpu

Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores. log-likelihood of the model must be computed.

Author

Annthomy Gilles, Alexandre Seiller

References

BaVe2018drimmR Ver08drimmR