Generic function computing the log-likelihood of the model x,
with the list of sequences sequences.
loglik(x, sequences, ncpu = 2)A list of loglikelihood (numeric)
An object for which the log-likelihood of the DMM can be computed.
A vector of character or list of vectors representing the sequences for which the
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores. log-likelihood of the model must be computed.
Annthomy Gilles, Alexandre Seiller
BaVe2018drimmR Ver08drimmR