powered by
Evaluate the log-likelihood of a drifting Markov Model
# S3 method for dmm loglik(x, sequences, ncpu = 2)
A list of log-likelihood (numeric)
An object of class dmm
dmm
A character vector or a list of character vectors representing the sequence
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.
Annthomy Gilles, Alexandre Seiller
BaVe2018drimmR Ver08drimmR
fitdmm, getTransitionMatrix
data(lambda, package = "drimmR") sequence <- c("a","g","g","t","c","g","a","t","a","a","a") dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum") loglik(dmm,sequence)
Run the code above in your browser using DataLab