| simulate | R Documentation |
Generic function simulating a sequence of length model_size under a model x
simulate(x, output_file, model_size = 1e+05, ncpu = 2)
x |
An object for which simulated sequences of the DMM can be computed. |
output_file |
(Optional) File containing the simulated sequence (e.g, "C:/.../SIM.txt") |
model_size |
Size of the model |
ncpu |
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores. |
the vector of simulated sequence
Annthomy Gilles, Alexandre Seiller
BaVe2018drimmR \insertRefVer08drimmR
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.