| stationary_distributions | R Documentation |
Stationary laws for a range of positions between <start> and <end>
stationary_distributions(
x,
start = 1,
end = NULL,
step = NULL,
output_file = NULL,
plot = FALSE
)
x |
An object of class |
start |
Start position : a positive integer giving the start position along the sequence from which the stationary laws of the DMM should be computed |
end |
End position : a positive integer giving the end position along the sequence until which the stationary laws of the DMM should be computed |
step |
A step (integer) |
output_file |
(Optional) A file containing matrix of stationary laws (e.g, "C:/.../SL.txt") |
plot |
|
A matrix with positions and stationary laws of states
Alexandre Seiller
BaVe2018drimmR \insertRefVer08drimmR
fitdmm, getStationaryLaw
data(lambda, package = "drimmR")
dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq",fit.method="sum")
stationary_distributions(dmm,start=1,end=1000,step=100, plot=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.