powered by
Stationary laws for a range of positions between <start> and <end>
stationary_distributions( x, start = 1, end = NULL, step = NULL, output_file = NULL, plot = FALSE )
A matrix with positions and stationary laws of states
An object of class dmm
dmm
Start position : a positive integer giving the start position along the sequence from which the stationary laws of the DMM should be computed
End position : a positive integer giving the end position along the sequence until which the stationary laws of the DMM should be computed
A step (integer)
(Optional) A file containing matrix of stationary laws (e.g, "C:/.../SL.txt")
FALSE (default); TRUE (display a figure plot of stationary distribution probabilities by position)
FALSE
TRUE
Alexandre Seiller
BaVe2018drimmR Ver08drimmR
fitdmm, getStationaryLaw
data(lambda, package = "drimmR") dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq",fit.method="sum") stationary_distributions(dmm,start=1,end=1000,step=100, plot=TRUE)
Run the code above in your browser using DataLab