powered by
Probability of a word at a position t of a DMM
word_probability(word, pos, x, output_file = NULL, internal = FALSE, ncpu = 2)
A numeric, probability of word
word
A subsequence (string of characters)
A position (numeric)
An object of class dmm
dmm
(Optional) A file containing the probability (e.g,"C:/.../PROB.txt")
FALSE (default) ; TRUE (for internal use of word applications)
FALSE
TRUE
Default=2. Represents the number of cores used to parallelized computation. If ncpu=-1, then it uses all available cores.
Victor Mataigne, Alexandre Seiller
BaVe2018drimmR Ver08drimmR
fitdmm, getTransitionMatrix, word_probabilities, words_probabilities
data(lambda, package = "drimmR") dmm <- fitdmm(lambda, 1, 1, c('a','c','g','t'), init.estim = "freq", fit.method="sum") word_probability("aggctga",4,dmm)
Run the code above in your browser using DataLab